summaryrefslogtreecommitdiffstats
path: root/src/daemon/cpulimit.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/daemon/cpulimit.h')
-rw-r--r--src/daemon/cpulimit.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/daemon/cpulimit.h b/src/daemon/cpulimit.h
index f3c5534d..21bdd17b 100644
--- a/src/daemon/cpulimit.h
+++ b/src/daemon/cpulimit.h
@@ -4,27 +4,27 @@
/* $Id$ */
/***
- This file is part of polypaudio.
+ This file is part of PulseAudio.
- polypaudio is free software; you can redistribute it and/or modify
+ PulseAudio is free software; you can redistribute it and/or modify
it under the terms of the GNU Lesser General Public License as published
by the Free Software Foundation; either version 2 of the License,
or (at your option) any later version.
- polypaudio is distributed in the hope that it will be useful, but
+ PulseAudio is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
General Public License for more details.
You should have received a copy of the GNU Lesser General Public License
- along with polypaudio; if not, write to the Free Software
+ along with PulseAudio; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
USA.
***/
#include <polyp/mainloop-api.h>
/* This kills the polypaudio process if it eats more than 70% of the
* CPU time. This is build around setrlimit() and SIGXCPU. It is handy
* in case of using SCHED_FIFO which may freeze the whole machine */
@@ -4,27 +4,27 @@
USA.
***/
-#include <polyp/mainloop-api.h>
+#include <pulse/mainloop-api.h>
-/* This kills the polypaudio process if it eats more than 70% of the
+/* This kills the pulseaudio process if it eats more than 70% of the
* CPU time. This is build around setrlimit() and SIGXCPU. It is handy
* in case of using SCHED_FIFO which may freeze the whole machine */